@@ -179,6 +179,10 @@ class Feedback(object):
             infr.verbose = verbose
         edge = aid1, aid2 = nxu.e_(*edge)
 
+        if aid1 is None or aid2 is None:
+            logger.error('add_feedback(aid1=None, aid2=None) called, ignoring')
+            return
+
         if not infr.has_edge(edge):
             if True:
                 # Allow new aids
@@ -1267,8 +1271,8 @@ class AnnotInference(
         infr.task_thresh_dict = {
             'zebra_grevys': {
                 'match_state': {
-                    POSTV: 0.7312,  # GGR2 - 0.7732, Kaia CA - 0.7312
-                    NEGTV: 0.8892,  # GGR2 - 0.8605, Kaia CA - 0.8892
+                    POSTV: 0.7732,  # GGR2 - 0.7732, Kaia CA - 0.7312
+                    NEGTV: 0.8605,  # GGR2 - 0.8605, Kaia CA - 0.8892
                     INCMP: np.inf,
                 },
                 'photobomb_state': {'pb': np.inf, 'nopb': np.inf},
