@@ -86,31 +86,22 @@ class InfrLoops(object):
             # quick startup. Yield a bunch of random edges
             num = infr.params['manual.n_peek']
             user_request = []
-            try:
-                for edge in ut.random_combinations(infr.aids, 2, num=num):
-                    user_request += [infr._make_review_tuple(edge, None)]
-                    yield user_request
-            except StopIteration:
-                pass
+            for edge in ut.random_combinations(infr.aids, 2, num=num):
+                user_request += [infr._make_review_tuple(edge, None)]
+                yield user_request
 
         if infr.params['algo.hardcase']:
             infr.loop_phase = 'hardcase_init'
             # Check previously labeled edges that where the groundtruth and the
             # verifier disagree.
-            try:
-                for _ in infr.hardcase_review_gen():
-                    yield _
-            except StopIteration:
-                pass
+            for _ in infr.hardcase_review_gen():
+                yield _
 
         if infr.params['inference.enabled']:
             infr.loop_phase = 'incon_recover_init'
             # First, fix any inconsistencies
-            try:
-                for _ in infr.incon_recovery_gen():
-                    yield _
-            except StopIteration:
-                pass
+            for _ in infr.incon_recovery_gen():
+                yield _
 
         # Phase 0.2: Ensure positive redundancy (this is generally quick)
         # so the user starts seeing real work after one random review is made
@@ -118,25 +109,18 @@ class InfrLoops(object):
         if infr.params['redun.enabled'] and infr.params['redun.enforce_pos']:
             infr.loop_phase = 'pos_redun_init'
             # Fix positive redundancy of anything within the loop
-            try:
-                for _ in infr.pos_redun_gen():
-                    yield _
-            except StopIteration:
-                pass
+            for _ in infr.pos_redun_gen():
+                yield _
 
         infr.phase = 1
         if infr.params['ranking.enabled']:
             for count in it.count(0):
-
                 infr.print('Outer loop iter %d ' % (count,))
 
                 # Phase 1: Try to merge PCCs by searching for LNBNN candidates
                 infr.loop_phase = 'ranking_{}'.format(count)
-                try:
-                    for _ in infr.ranked_list_gen(use_refresh):
-                        yield _
-                except StopIteration:
-                    pass
+                for _ in infr.ranked_list_gen(use_refresh):
+                    yield _
 
                 terminate = infr.refresh.num_meaningful == 0
                 if terminate:
@@ -147,11 +131,8 @@ class InfrLoops(object):
                 infr.loop_phase = 'posredun_{}'.format(count)
                 if all(ut.take(infr.params, ['redun.enabled', 'redun.enforce_pos'])):
                     # Fix positive redundancy of anything within the loop
-                    try:
-                        for _ in infr.pos_redun_gen():
-                            yield _
-                    except StopIteration:
-                        pass
+                    for _ in infr.pos_redun_gen():
+                        yield _
 
                 logger.info('prob_any_remain = %r' % (infr.refresh.prob_any_remain(),))
                 logger.info(
@@ -175,11 +156,8 @@ class InfrLoops(object):
             # asking the user to do anything but resolve inconsistency.
             infr.print('Entering phase 3', 1, color='red')
             infr.loop_phase = 'negredun'
-            try:
-                for _ in infr.neg_redun_gen():
-                    yield _
-            except StopIteration:
-                pass
+            for _ in infr.neg_redun_gen():
+                yield _
 
         infr.phase = 4
         infr.print('Terminate', 1, color='red')
@@ -504,11 +482,8 @@ class InfrLoops(object):
         """
         infr.start_id_review(max_loops=max_loops, use_refresh=use_refresh)
         # To automatically run through the loop just exhaust the generator
-        try:
-            result = next(infr._gen)
-            assert result is None, 'need user interaction. cannot auto loop'
-        except StopIteration:
-            pass
+        result = next(infr._gen)
+        assert result is None, 'need user interaction. cannot auto loop'
         infr._gen = None
 
 
