@@ -243,10 +243,8 @@ def k_edge_augmentation(G, k, avail=None, weight=None, partial=False):
         try:
             for edge in list(aug_edges):
                 yield edge
-        except StopIteration:
-            pass
         except RuntimeError:
-            pass
+            return
     except nx.NetworkXUnfeasible:
         if partial:
             # Return all available edges
@@ -261,10 +259,8 @@ def k_edge_augmentation(G, k, avail=None, weight=None, partial=False):
             try:
                 for edge in aug_edges:
                     yield edge
-            except StopIteration:
-                pass
             except RuntimeError:
-                pass
+                return
         else:
             raise
 
