@@ -34,7 +34,25 @@ CommandLine:
     python dev.py --wshow -t query --db PZ_MTEST --qaid 110 --cfg fg_on=True
     python dev.py --wshow -t query --db PZ_MTEST --qaid 110 --cfg
 """
+import os
+
 # TODO: ADD COPYRIGHT TAG
+try:
+    import sentry_sdk
+    from sentry_sdk.integrations.flask import FlaskIntegration
+except ImportError:
+    pass
+else:
+    dsn = os.getenv(
+        'WBIA_SENTRY_DSN',
+        default='https://30f53fef7e7d44bc8b9446f05cf90dd7@sentry.dyn.wildme.io/2',
+    )
+    sentry_sdk.init(
+        dsn=dsn,
+        integrations=[FlaskIntegration()],
+    )
+    del dsn
+
 try:
     import multiprocessing as mp
 
@@ -50,18 +68,22 @@ try:
 except (ImportError, RuntimeError):
     pass
 
-import logging
-import sys
-import numpy as np
+import logging  # NOQA
 
-from wbia._devscript import devcmd, DEVCMD_FUNCTIONS, DEVPRECMD_FUNCTIONS
-import utool as ut
-from utool.util_six import get_funcname
-import utool
+root_logger = logging.getLogger()  # NOQA
+root_logger.setLevel(logging.INFO)  # NOQA
+
+import sys  # NOQA
+import numpy as np  # NOQA
+
+from wbia._devscript import devcmd, DEVCMD_FUNCTIONS, DEVPRECMD_FUNCTIONS  # NOQA
+import utool as ut  # NOQA
+from utool.util_six import get_funcname  # NOQA
+import utool  # NOQA
 
 # from wbia.algo.hots import smk
-import wbia.plottool as pt
-import wbia
+import wbia.plottool as pt  # NOQA
+import wbia  # NOQA
 
 # import multiprocessing
 # if __name__ == '__main__':
@@ -101,7 +123,7 @@ from wbia.init import main_helpers  # NOQA
 from wbia.other import dbinfo  # NOQA
 from wbia.expt import experiment_configs  # NOQA
 from wbia.expt import harness  # NOQA
-from wbia.expt.experiment_drawing import draw_annot_scoresep
+from wbia.expt.experiment_drawing import draw_annot_scoresep  # NOQA
 from wbia import params  # NOQA
 
 print, rrr, profile = utool.inject2(__name__)
